==> newsstar-1.2.2.tar.gz: newsstar-1.2.2/src/nntp.h <==
#ifndef NNTP_H 
#define NNTP_H

/*
    newsstar - advanced news fetcher
    Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* For communicating with NNTP server */

/* $Id: nntp.h,v 1.4 2003/12/08 15:45:37 realh Exp $ */

#ifndef DEBLOG_H
#include "deblog.h"
#endif
#ifndef RW_H
#include "rw.h"
#endif

/* Not strictly NNTP, but... Returns address in dotquad notation or NULL */
char *nntp_resolve_address(const char *name);

/* Returns response or NULL if problem. message should contain %s for response,
 * but no trailing \n or : . allow contains each character allowed at start of
 * response eg "23". log_level is level at which any problems are reported. */
const char *nntp_check_response(rw_buf *, const char *message, const char
	*allow, deblog_level_t log_level);

/* Returns buffered socket */
rw_buf *nntp_connect(const char *dotquad, int port, int thread_idx, BOOL ssl);

/* Returns TRUE if there's a problem */
BOOL nntp_authenticate(rw_buf *, const char *user, const char *passwd);

/* Returns TRUE if there's a problem; mode is "STREAM" or "READER" */
BOOL nntp_set_mode(rw_buf *, const char *mode);

/* Returns TRUE if there's a problem, otherwise fills in first and last
 * available article numbers (both must be non-NULL for either to be filled in
 */
BOOL nntp_enter_group(rw_buf *, const char *groupname, long int *first, long
	int *last, BOOL check_response);

#endif /* NNTP_H */

==> newsstar-1.3.2.tar.gz: newsstar-1.3.2/src/nntp.h <==
#ifndef NNTP_H 
#define NNTP_H

/*
    newsstar - advanced news fetcher
    Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* For communicating with NNTP server */


#ifndef DEBLOG_H
#include "deblog.h"
#endif
#ifndef RW_H
#include "rw.h"
#endif

/* Not strictly NNTP, but... Returns address in dotquad notation or NULL */
char *nntp_resolve_address(const char *name);

/* Returns response or NULL if problem. message should contain %s for response,
 * but no trailing \n or : . allow contains each character allowed at start of
 * response eg "23". log_level is level at which any problems are reported. */
const char *nntp_check_response(rw_buf *, const char *server_name,
	const char *message, const char *allow, deblog_level_t log_level);

/* Returns buffered socket */
rw_buf *nntp_connect(const char *server_name, const char *dotquad,
	int port, int thread_idx, BOOL ssl);

/* Returns TRUE if there's a problem */
BOOL nntp_authenticate(rw_buf *, const char *server_name,
	const char *user, const char *passwd);

/* Returns TRUE if there's a problem; mode is "STREAM" or "READER" */
BOOL nntp_set_mode(rw_buf *, const char *server_name, const char *mode);

/* Returns TRUE if there's a problem, otherwise fills in first and last
 * available article numbers (both must be non-NULL for either to be filled in
 */
BOOL nntp_enter_group(rw_buf *, const char *server_name, const char *groupname,
	long int *first, long int *last, BOOL check_response);

#endif /* NNTP_H */
